@@ -229,7 +229,11 @@ protected:
     void saveLayout();
 
     QStringList mimeTypes() const override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QMimeData *mimeData(const QList<QTreeWidgetItem *> items) const override;
+#else
+    QMimeData *mimeData(const QList<QTreeWidgetItem *> &items) const override;
+#endif
     Qt::DropActions supportedDropActions() const override;
 
     void sendReloadMenu();
